@@ -1,7 +1,7 @@
 package Perinci::Sub::XCompletion::filename;
 
-our $DATE = '2015-11-06'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-07-22'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,7 +18,10 @@ sub gen_completion {
     my %fargs = @_;
     sub {
         my %cargs = @_;
-        complete_file(%cargs, %fargs);
+        hashify_answer(
+            complete_file(%cargs, %fargs),
+            {path_sep => '/'},
+        );
     };
 }
 
@@ -37,7 +40,7 @@ Perinci::Sub::XCompletion::filename - Generate completion for filename
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::Sub::XCompletion::filename (from Perl distribution Perinci-Sub-XCompletion), released on 2015-11-06.
+This document describes version 0.06 of Perinci::Sub::XCompletion::filename (from Perl distribution Perinci-Sub-XCompletion), released on 2016-07-22.
 
 =head1 SYNOPSIS
 
@@ -46,7 +49,7 @@ This document describes version 0.05 of Perinci::Sub::XCompletion::filename (fro
 
 =head2 gen_completion() -> [status, msg, result, meta]
 
-This function is not exportable.
+This function is not exported.
 
 No arguments.
 
@@ -83,7 +86,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
